# Aerospace Chatbot
Aerospace discipline-specific chatbots and AI tools.
Help docs here: https://aerospace-chatbot.readthedocs.io/en/latest/

## Deployments
There is a deployment of Aerospace Chatbot, loaded with all Aerospace Mecahnism Symposia papers located in [/data/AMS/](https://github.com/dan-s-mueller/aerospace_chatbot/tree/main/data/AMS).

[Aerospace Chatbot, Aerospace Mechanisms Symposia](https://huggingface.co/spaces/ai-aerospace/aerospace_chatbot_ams)
